@@ -7,11 +7,11 @@ from __future__ import annotations
 #
 # If everything works well you should find a subdirectory in the build
 # subdirectory that contains the files needed to run the script without Python
-from cx_Freeze import Executable, setup
+from cx_Freeze import setup
 
 setup(
     name="test",
     version="0.1",
     description="cx_Freeze script to test pycountry",
-    executables=[Executable("test.py")],
+    executables=["test.py"],
 )
