@@ -497,17 +497,17 @@ class TempPackageVenv(TempPackage):
         if IS_CONDA:
             self.prefix = self.venv_prefix
             self.python = self.venv_python
-        else:
-            # PYTHONPATH is the key here
-            if env is None:
-                env = os.environ.copy()
-            venv_site = os.path.normpath(self.venv_prefix / self.relative_site)
-            env["PYTHONPATH"] = venv_site
-        try:
-            return super().freeze(command, cwd, env, timeout)
-        finally:
-            self.prefix = self._prefix
-            self.python = self._python
+            try:
+                return super().freeze(command, cwd, env, timeout)
+            finally:
+                self.prefix = self._prefix
+                self.python = self._python
+        # PYTHONPATH is the key here
+        if env is None:
+            env = os.environ.copy()
+        venv_site = os.path.normpath(self.venv_prefix / self.relative_site)
+        env["PYTHONPATH"] = venv_site
+        return super().freeze(command, cwd, env, timeout)
 
     def install(
         self,
